==> ukui-sidebar_3.0.1.orig.tar.gz: ukui-sidebar/translations/ukui-sidebar-notification/ukui-sidebar-notification_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="65"/>
        <source>Notification center</source>
        <translation type="unfinished">通知中心</translation>
    </message>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="112"/>
        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="681"/>
        <source>Important notice</source>
        <translation type="unfinished">重要的通知</translation>
    </message>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="120"/>
        <source>Clean up</source>
        <translation type="unfinished">清空</translation>
    </message>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="151"/>
        <source>Set up</source>
        <translation type="unfinished">设置</translation>
    </message>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="217"/>
        <source>No new notifications</source>
        <translation type="unfinished">没有新通知</translation>
    </message>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="240"/>
        <source>No unimportant notice</source>
        <translation type="unfinished">没有不重要的通知</translation>
    </message>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="653"/>
        <source>Unimportant notice</source>
        <translation type="unfinished">不重要的通知</translation>
    </message>
</context>
<context>
    <name>SingleMsg</name>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/singlemsg.cpp" line="116"/>
        <source>now</source>
        <translation type="unfinished">现在</translation>
    </message>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/singlemsg.cpp" line="284"/>
        <source>Yesterday </source>
        <translation type="unfinished">昨天 </translation>
    </message>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/singlemsg.cpp" line="363"/>
        <source>In addition </source>
        <translation type="unfinished">还有 </translation>
    </message>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/singlemsg.cpp" line="363"/>
        <source> notification</source>
        <translation type="unfinished"> 则通知</translation>
    </message>
    <message>
        <source>In addition</source>
        <translation type="obsolete">还有</translation>
    </message>
</context>
<context>
    <name>TakeInBoxToolButton</name>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/takeinboxtoolbutton.cpp" line="36"/>
        <source>Enter unimportant news</source>
        <translation type="unfinished">进入不重要通知</translation>
    </message>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/takeinboxtoolbutton.cpp" line="41"/>
        <source>Quit unimportant news</source>
        <translation type="unfinished">退出不重要通知</translation>
    </message>
</context>
</TS>

==> ukui-sidebar_3.1.1.orig.tar.gz: ukui-sidebar/translations/ukui-sidebar-notification/ukui-sidebar-notification_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="65"/>
        <source>Notification center</source>
        <translation>通知中心</translation>
    </message>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="112"/>
        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="681"/>
        <source>Important notice</source>
        <translation>重要的通知</translation>
    </message>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="120"/>
        <source>Clean up</source>
        <translation>清空</translation>
    </message>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="151"/>
        <source>Set up</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="217"/>
        <source>No new notifications</source>
        <translation>没有新通知</translation>
    </message>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="240"/>
        <source>No unimportant notice</source>
        <translation>没有不重要的通知</translation>
    </message>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="653"/>
        <source>Unimportant notice</source>
        <translation>不重要的通知</translation>
    </message>
</context>
<context>
    <name>SingleMsg</name>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/singlemsg.cpp" line="116"/>
        <source>now</source>
        <translation>现在</translation>
    </message>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/singlemsg.cpp" line="284"/>
        <source>Yesterday </source>
        <translation>昨天 </translation>
    </message>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/singlemsg.cpp" line="363"/>
        <source>In addition </source>
        <translation>还有 </translation>
    </message>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/singlemsg.cpp" line="363"/>
        <source> notification</source>
        <translation type="unfinished"> 则通知</translation>
    </message>
    <message>
        <source>In addition</source>
        <translation type="obsolete">还有</translation>
    </message>
</context>
<context>
    <name>TakeInBoxToolButton</name>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/takeinboxtoolbutton.cpp" line="36"/>
        <source>Enter unimportant news</source>
        <translation type="unfinished">进入不重要通知</translation>
    </message>
    <message>
        <location filename="../../src/plugins/ukui-sidebar-notification/takeinboxtoolbutton.cpp" line="41"/>
        <source>Quit unimportant news</source>
        <translation type="unfinished">退出不重要通知</translation>
    </message>
</context>
</TS>
